@@ -1,3 +1,5 @@
+"""Tests for the Model, CompositeModel, and ModelResult classes."""
+
 import functools
 import sys
 import unittest
@@ -7,11 +9,502 @@ import numpy as np
 from numpy.testing import assert_allclose
 import pytest
 
+import lmfit
 from lmfit import Model, models
 from lmfit.lineshapes import gaussian
+from lmfit.model import get_reducer, propagate_err
 from lmfit.models import PseudoVoigtModel
 
 
+@pytest.fixture()
+def gmodel():
+    """Return a Gaussian model."""
+    return Model(lmfit.lineshapes.gaussian)
+
+
+def test_get_reducer_invalid_option():
+    """Tests for ValueError when using an unsupported option."""
+    option = 'unknown'
+    msg = r'Invalid option'
+    with pytest.raises(ValueError, match=msg):
+        get_reducer(option)
+
+
+test_data_get_reducer = [('real', [1.0, 1.0, 2.0, 2.0]),
+                         ('imag', [0.0, 10.0, 0.0, 20.0]),
+                         ('abs', [1.0, 10.04987562, 2.0, 20.09975124]),
+                         ('angle', [0.0, 1.47112767, 0.0, 1.471127670])]
+
+
+@pytest.mark.parametrize('option, expected_array', test_data_get_reducer)
+def test_get_reducer(option, expected_array):
+    """Tests for ValueError when using an unsupported option."""
+    complex_array = np.array([1.0, 1.0+10j, 2.0, 2.0+20j], dtype='complex')
+    func = get_reducer(option)
+    real_array = func(complex_array)
+
+    assert np.all(np.isreal(real_array))
+    assert_allclose(real_array, expected_array)
+
+    # nothing should happen to an array that only contains real data
+    assert_allclose(func(real_array), real_array)
+
+
+def test_propagate_err_invalid_option():
+    """Tests for ValueError when using an unsupported option."""
+    z = np.array([0, 1, 2, 3, 4, 5])
+    dz = np.random.normal(size=z.size, scale=0.1)
+    option = 'unknown'
+    msg = r'Invalid option'
+    with pytest.raises(ValueError, match=msg):
+        propagate_err(z, dz, option)
+
+
+def test_propagate_err_unequal_shape_z_dz():
+    """Tests for ValueError when using unequal arrays for z and dz."""
+    z = np.array([0, 1, 2, 3, 4, 5])
+    dz = np.random.normal(size=z.size-1, scale=0.1)
+    msg = r'shape of z:'
+    with pytest.raises(ValueError, match=msg):
+        propagate_err(z, dz, option='abs')
+
+
+@pytest.mark.parametrize('option', ['real', 'imag', 'abs', 'angle'])
+def test_propagate_err(option):
+    """Tests for ValueError when using an unsupported option."""
+    np.random.seed(2020)
+    z = np.array([1.0, 1.0+10j, 2.0, 2.0+20j], dtype='complex')
+    dz = np.random.normal(z.size, scale=0.1)*z
+
+    # if `z` is real, assume that `dz` is also real and return it as-is
+    err = propagate_err(np.real(z), np.real(dz), option)
+    assert_allclose(err, np.real(dz))
+
+    # if `z` is complex, but `dz` is real apply the err to both real/imag
+    err_complex_real = propagate_err(z, np.real(dz), option)
+    assert np.all(np.isreal(err_complex_real))
+    dz_used = np.real(dz)+1j*np.real(dz)
+    if option == 'real':
+        assert_allclose(err_complex_real, np.real(dz_used))
+    elif option == 'imag':
+        assert_allclose(err_complex_real, np.imag(dz_used))
+    elif option == 'abs':
+        assert_allclose(err_complex_real,
+                        [3.823115, 3.823115, 7.646231, 7.646231],
+                        rtol=1.0e-5)
+    elif option == 'angle':
+        assert_allclose(err_complex_real,
+                        [3.823115, 0.380414, 3.823115, 0.380414],
+                        rtol=1.0e-5)
+
+    # both `z` and `dz` are complex
+    err_complex_complex = propagate_err(z, dz, option)
+    assert np.all(np.isreal(err_complex_complex))
+    if option == 'real':
+        assert_allclose(err_complex_complex, np.real(dz))
+    elif option == 'imag':
+        assert_allclose(err_complex_complex, np.imag(dz))
+    elif option == 'abs':
+        assert_allclose(err_complex_complex,
+                        [3.823115, 38.043322, 7.646231, 76.086645],
+                        rtol=1.0e-5)
+    elif option == 'angle':
+        assert_allclose(err_complex_complex, [0., 0.535317, 0., 0.535317],
+                        rtol=1.0e-5)
+
+
+def test_initialize_Model_class_default_arguments(gmodel):
+    """Test for Model class initialized with default arguments."""
+    assert gmodel.prefix == ''
+    assert gmodel._param_root_names == ['amplitude', 'center', 'sigma']
+    assert gmodel.param_names == ['amplitude', 'center', 'sigma']
+    assert gmodel.independent_vars == ['x']
+    assert gmodel.nan_policy == 'raise'
+    assert gmodel.name == 'Model(gaussian)'
+    assert gmodel.opts == {}
+    assert gmodel.def_vals == {'amplitude': 1.0, 'center': 0.0, 'sigma': 1.0}
+
+
+def test_initialize_Model_class_independent_vars():
+    """Test for Model class initialized with independent_vars."""
+    model = Model(lmfit.lineshapes.gaussian, independent_vars=['amplitude'])
+    assert model._param_root_names == ['x', 'center', 'sigma']
+    assert model.param_names == ['x', 'center', 'sigma']
+    assert model.independent_vars == ['amplitude']
+
+
+def test_initialize_Model_class_param_names():
+    """Test for Model class initialized with param_names."""
+    model = Model(lmfit.lineshapes.gaussian, param_names=['amplitude'])
+
+    assert model._param_root_names == ['amplitude']
+    assert model.param_names == ['amplitude']
+
+
+@pytest.mark.parametrize("policy", ['raise', 'omit', 'propagate'])
+def test_initialize_Model_class_nan_policy(policy):
+    """Test for Model class initialized with nan_policy."""
+    model = Model(lmfit.lineshapes.gaussian, nan_policy=policy)
+
+    assert model.nan_policy == policy
+
+
+def test_initialize_Model_class_prefix():
+    """Test for Model class initialized with prefix."""
+    model = Model(lmfit.lineshapes.gaussian, prefix='test_')
+
+    assert model.prefix == 'test_'
+    assert model._param_root_names == ['amplitude', 'center', 'sigma']
+    assert model.param_names == ['test_amplitude', 'test_center', 'test_sigma']
+    assert model.name == "Model(gaussian, prefix='test_')"
+
+    model = Model(lmfit.lineshapes.gaussian, prefix=None)
+
+    assert model.prefix == ''
+
+
+def test_initialize_Model_name():
+    """Test for Model class initialized with name."""
+    model = Model(lmfit.lineshapes.gaussian, name='test_function')
+
+    assert model.name == 'Model(test_function)'
+
+
+def test_initialize_Model_kws():
+    """Test for Model class initialized with **kws."""
+    kws = {'amplitude': 10.0}
+    model = Model(lmfit.lineshapes.gaussian,
+                  independent_vars=['x', 'amplitude'], **kws)
+
+    assert model._param_root_names == ['center', 'sigma']
+    assert model.param_names == ['center', 'sigma']
+    assert model.independent_vars == ['x', 'amplitude']
+    assert model.opts == kws
+
+
+test_reprstring_data = [(False, 'Model(gaussian)'),
+                        (True, "Model(gaussian, amplitude='10.0')")]
+
+
+@pytest.mark.parametrize("option, expected", test_reprstring_data)
+def test_Model_reprstring(option, expected):
+    """Test for Model class function _reprstring."""
+    kws = {'amplitude': 10.0}
+    model = Model(lmfit.lineshapes.gaussian,
+                  independent_vars=['x', 'amplitude'], **kws)
+
+    assert model._reprstring(option) == expected
+
+
+def test_Model_get_state(gmodel):
+    """Test for Model class function _get_state."""
+    out = gmodel._get_state()
+
+    assert isinstance(out, tuple)
+    assert out[1] == out[2] is None
+    assert (out[0][1] is not None) == lmfit.jsonutils.HAS_DILL
+
+    assert out[0][0] == 'gaussian'
+    assert out[0][2:] == ('gaussian', '', ['x'],
+                          ['amplitude', 'center', 'sigma'], {}, 'raise', {})
+
+
+def test_Model_set_state(gmodel):
+    """Test for Model class function _set_state.
+
+    This function is just calling `_buildmodel`, which will be tested
+    below together with the use of `funcdefs`.
+
+    """
+    out = gmodel._get_state()
+
+    new_model = Model(lmfit.lineshapes.lorentzian)
+    new_model = new_model._set_state(out)
+
+    assert new_model.prefix == gmodel.prefix
+    assert new_model._param_root_names == gmodel._param_root_names
+    assert new_model.param_names == gmodel.param_names
+    assert new_model.independent_vars == gmodel.independent_vars
+    assert new_model.nan_policy == gmodel.nan_policy
+    assert new_model.name == gmodel.name
+    assert new_model.opts == gmodel.opts
+
+
+def test_Model_dumps_loads(gmodel):
+    """Test for Model class functions dumps and loads.
+
+    These function are used when saving/loading the Model class and will be
+    tested more thoroughly in test_model_saveload.py.
+
+    """
+    model_json = gmodel.dumps()
+    _ = gmodel.loads(model_json)
+
+
+def test_Model_getter_setter_name(gmodel):
+    """Test for Model class getter/setter functions for name."""
+    assert gmodel.name == 'Model(gaussian)'
+
+    gmodel.name = 'test_gaussian'
+    assert gmodel.name == 'Model(test_gaussian)'
+
+
+def test_Model_getter_setter_prefix(gmodel):
+    """Test for Model class getter/setter functions for prefix."""
+    assert gmodel.prefix == ''
+    assert gmodel.param_names == ['amplitude', 'center', 'sigma']
+
+    gmodel.prefix = 'g1_'
+    assert gmodel.prefix == 'g1_'
+    assert gmodel.param_names == ['g1_amplitude', 'g1_center', 'g1_sigma']
+
+    gmodel.prefix = ''
+    assert gmodel.prefix == ''
+    assert gmodel.param_names == ['amplitude', 'center', 'sigma']
+
+
+def test_Model_getter_param_names(gmodel):
+    """Test for Model class getter function for param_names."""
+    assert gmodel.param_names == ['amplitude', 'center', 'sigma']
+
+
+def test_Model__repr__(gmodel):
+    """Test for Model class __repr__ method."""
+    assert gmodel.__repr__() == '<lmfit.Model: Model(gaussian)>'
+
+
+def test_Model_copy(gmodel):
+    """Test for Model class copy method."""
+    msg = 'Model.copy does not work. Make a new Model'
+    with pytest.raises(NotImplementedError, match=msg):
+        gmodel.copy()
+
+
+def test__parse_params_func_None():
+    """Test for _parse_params function with func=None."""
+    mod = Model(None)
+
+    assert mod._prefix == ''
+    assert mod.func is None
+    assert mod._func_allargs == []
+    assert mod._func_haskeywords is False
+    assert mod.independent_vars == []
+
+
+def test__parse_params_asteval_functions():
+    """Test for _parse_params function with asteval functions."""
+    # TODO: cannot find a use-case for this....
+    pass
+
+
+def test__parse_params_inspect_signature():
+    """Test for _parse_params function using inspect.signature."""
+    # 1. function with a positional argument
+    def func_var_positional(a, *b):
+        pass
+
+    with pytest.raises(ValueError, match=r"varargs '\*b' is not supported"):
+        Model(func_var_positional)
+
+    # 2. function with a keyword argument
+    def func_keyword(a, b, **c):
+        pass
+
+    mod = Model(func_keyword)
+    assert mod._func_allargs == ['a', 'b']
+    assert mod._func_haskeywords is True
+    assert mod.independent_vars == ['a']
+    assert mod.def_vals == {}
+
+    # 3. function with keyword argument only
+    def func_keyword_only(**b):
+        pass
+
+    mod = Model(func_keyword_only)
+    assert mod._func_allargs == []
+    assert mod._func_haskeywords is True
+    assert mod.independent_vars == []
+    assert mod._param_root_names is None
+
+    # 4. function with default value
+    def func_default_value(a, b, c=10):
+        pass
+
+    mod = Model(func_default_value)
+    assert mod._func_allargs == ['a', 'b', 'c']
+    assert mod._func_haskeywords is False
+    assert mod.independent_vars == ['a']
+
+    assert isinstance(mod.def_vals, dict)
+    assert_allclose(mod.def_vals['c'], 10)
+
+
+def test__parse_params_forbidden_variable_names():
+    """Tests for _parse_params function using invalid variable names."""
+
+    def func_invalid_var(data, a):
+        pass
+
+    def func_invalid_par(a, weights):
+        pass
+
+    msg = r"Invalid independent variable name \('data'\) for function func_invalid_var"
+    with pytest.raises(ValueError, match=msg):
+        Model(func_invalid_var)
+
+    msg = r"Invalid parameter name \('weights'\) for function func_invalid_par"
+    with pytest.raises(ValueError, match=msg):
+        Model(func_invalid_par)
+
+
+input_dtypes = [(np.int32, np.float64), (np.float32, np.float64),
+                (np.complex64, np.complex128), ('list', np.float64),
+                ('tuple', np.float64), ('pandas-real', np.float64),
+                ('pandas-complex', np.complex128)]
+
+
+@pytest.mark.parametrize('input_dtype, expected_dtype', input_dtypes)
+def test_coercion_of_input_data(peakdata, input_dtype, expected_dtype):
+    """Test for coercion of 'data' and 'independent_vars'.
+
+    - 'data' should become 'float64' or 'complex128'
+    - dtype for 'indepdendent_vars' is only changed when the input is a list,
+        tuple, numpy.ndarray, or pandas.Series
+
+    """
+    x, y = peakdata
+    model = lmfit.Model(gaussian)
+    pars = model.make_params()
+
+    if (not lmfit.minimizer.HAS_PANDAS and input_dtype in ['pandas-real',
+                                                           'pandas-complex']):
+        return
+
+    elif input_dtype == 'pandas-real':
+        result = model.fit(lmfit.model.Series(y, dtype=np.float32), pars,
+                           x=lmfit.model.Series(x, dtype=np.float32))
+    elif input_dtype == 'pandas-complex':
+        result = model.fit(lmfit.model.Series(y, dtype=np.complex64), pars,
+                           x=lmfit.model.Series(x, dtype=np.complex64))
+    elif input_dtype == 'list':
+        result = model.fit(y.tolist(), pars, x=x.tolist())
+    elif input_dtype == 'tuple':
+        result = model.fit(tuple(y), pars, x=tuple(x))
+    else:
+        result = model.fit(np.asarray(y, dtype=input_dtype), pars,
+                           x=np.asarray(x, dtype=input_dtype))
+
+    assert result.__dict__['userkws']['x'].dtype == expected_dtype
+    assert result.__dict__['userargs'][0].dtype == expected_dtype
+
+
+def test_figure_default_title(peakdata):
+    """Test default figure title."""
+    pytest.importorskip('matplotlib')
+
+    x, y = peakdata
+    pvmodel = PseudoVoigtModel()
+    params = pvmodel.guess(y, x=x)
+    result = pvmodel.fit(y, params, x=x)
+
+    ax = result.plot_fit()
+    assert ax.axes.get_title() == 'Model(pvoigt)'
+
+    ax = result.plot_residuals()
+    assert ax.axes.get_title() == 'Model(pvoigt)'
+
+    fig = result.plot()
+    assert fig.axes[0].get_title() == 'Model(pvoigt)'  # default model.name
+    assert fig.axes[1].get_title() == ''  # no title for fit subplot
+
+
+def test_figure_title_using_title_keyword_argument(peakdata):
+    """Test setting figure title using title keyword argument."""
+    pytest.importorskip('matplotlib')
+
+    x, y = peakdata
+    pvmodel = PseudoVoigtModel()
+    params = pvmodel.guess(y, x=x)
+    result = pvmodel.fit(y, params, x=x)
+
+    ax = result.plot_fit(title='test')
+    assert ax.axes.get_title() == 'test'
+
+    ax = result.plot_residuals(title='test')
+    assert ax.axes.get_title() == 'test'
+
+    fig = result.plot(title='test')
+    assert fig.axes[0].get_title() == 'test'
+    assert fig.axes[1].get_title() == ''  # no title for fit subplot
+
+
+def test_figure_title_using_title_to_ax_kws(peakdata):
+    """Test setting figure title by supplying ax_{fit,res}_kws."""
+    pytest.importorskip('matplotlib')
+
+    x, y = peakdata
+    pvmodel = PseudoVoigtModel()
+    params = pvmodel.guess(y, x=x)
+    result = pvmodel.fit(y, params, x=x)
+
+    ax = result.plot_fit(ax_kws={'title': 'ax_kws'})
+    assert ax.axes.get_title() == 'ax_kws'
+
+    ax = result.plot_residuals(ax_kws={'title': 'ax_kws'})
+    assert ax.axes.get_title() == 'ax_kws'
+
+    fig = result.plot(ax_res_kws={'title': 'ax_res_kws'})
+    assert fig.axes[0].get_title() == 'ax_res_kws'
+    assert fig.axes[1].get_title() == ''
+
+    fig = result.plot(ax_fit_kws={'title': 'ax_fit_kws'})
+    assert fig.axes[0].get_title() == 'Model(pvoigt)'  # default model.name
+    assert fig.axes[1].get_title() == ''  # no title for fit subplot
+
+
+def test_priority_setting_figure_title(peakdata):
+    """Test for setting figure title: title keyword argument has priority."""
+    pytest.importorskip('matplotlib')
+
+    x, y = peakdata
+    pvmodel = PseudoVoigtModel()
+    params = pvmodel.guess(y, x=x)
+    result = pvmodel.fit(y, params, x=x)
+
+    ax = result.plot_fit(ax_kws={'title': 'ax_kws'}, title='test')
+    assert ax.axes.get_title() == 'test'
+
+    ax = result.plot_residuals(ax_kws={'title': 'ax_kws'}, title='test')
+    assert ax.axes.get_title() == 'test'
+
+    fig = result.plot(ax_res_kws={'title': 'ax_res_kws'}, title='test')
+    assert fig.axes[0].get_title() == 'test'
+    assert fig.axes[1].get_title() == ''
+
+    fig = result.plot(ax_fit_kws={'title': 'ax_fit_kws'}, title='test')
+    assert fig.axes[0].get_title() == 'test'
+    assert fig.axes[1].get_title() == ''
+
+
+def test_guess_requires_x():
+    """Test to make sure that ``guess()`` method requires the argument ``x``.
+
+    The ``guess`` method needs ``x`` values (i.e., the independent variable)
+    to estimate initial parameters, but this was not a required argument.
+    See GH #747.
+
+    """
+    mod = lmfit.model.Model(gaussian)
+
+    msg = r"guess\(\) missing 2 required positional arguments: 'data' and 'x'"
+    with pytest.raises(TypeError, match=msg):
+        mod.guess()
+
+
+# Below is the content of the original test_model.py file. These tests still
+# need to be checked and possibly updated to the pytest-style. They work fine
+# though so leave them in for now.
+
 def assert_results_close(actual, desired, rtol=1e-03, atol=1e-03, err_msg='',
                          verbose=True):
     for param_name, value in desired.items():
@@ -19,13 +512,6 @@ def assert_results_close(actual, desired, rtol=1e-03, atol=1e-03, err_msg='',
                         verbose)
 
 
-def _skip_if_no_pandas():
-    try:
-        import pandas  # noqa: F401
-    except ImportError:
-        raise pytest.skip("Skipping tests that require pandas.")
-
-
 def firstarg_ndarray(func):
     """a simple wrapper used for testing that wrapped
     functions can be model functions"""
@@ -79,7 +565,7 @@ class CommonTests:
         assert_results_close(result.values, self.true_values())
 
         # Pass inidividual Parameter objects as kwargs.
-        kwargs = {name: p for name, p in params.items()}
+        kwargs = dict(params.items())
         result = self.model.fit(self.data, x=self.x, **kwargs)
         assert_results_close(result.values, self.true_values())
 
@@ -168,7 +654,8 @@ class CommonTests:
         assert " chi-square " in report
 
     def test_data_alignment(self):
-        _skip_if_no_pandas()
+        pytest.importorskip('pandas')
+
         from pandas import Series
 
         # Align data and indep var of different lengths using pandas index.
@@ -494,9 +981,10 @@ class TestUserDefiniedModel(CommonTests, unittest.TestCase):
         for _, par in pars.items():
             assert len(repr(par)) > 5
 
+    @pytest.mark.skipif(not lmfit.model._HAS_MATPLOTLIB,
+                        reason="requires matplotlib.pyplot")
     def test_composite_plotting(self):
         # test that a composite model has non-empty best_values
-        pytest.importorskip("matplotlib")
         import matplotlib
         matplotlib.use('Agg')
 
@@ -519,10 +1007,9 @@ class TestUserDefiniedModel(CommonTests, unittest.TestCase):
         pars['g2_amplitude'].set(1)
 
         result = mod.fit(data, params=pars, x=self.x)
-        fig, ax = result.plot(show_init=True)
+        fig = result.plot(show_init=True)
 
         assert isinstance(fig, matplotlib.figure.Figure)
-        assert isinstance(ax, matplotlib.axes.GridSpec)
 
         comps = result.eval_components(x=self.x)
         assert len(comps) == 2
@@ -574,7 +1061,7 @@ class TestUserDefiniedModel(CommonTests, unittest.TestCase):
             m.set_param_hint('amp', value=1)
             m.set_param_hint('amp', value=25)
 
-            models[i] = Model(func, prefix='mod%i_' % i)
+            models[i] = Model(func, prefix=f'mod{i}')
             models[i].param_hints['amp'] = m.param_hints['amp']
 
         self.assertEqual(models[0].param_hints['amp'],
@@ -586,6 +1073,59 @@ class TestUserDefiniedModel(CommonTests, unittest.TestCase):
         params = pmod.make_params(sigma=2, fraction=0.77)
         assert_allclose(params['fraction'].value, 0.77, rtol=0.01)
 
+    def test_symmetric_boundss(self):
+        # tests Github Issue 700
+        np.random.seed(0)
+
+        x = np.linspace(0, 20, 51)
+        y = gaussian(x, amplitude=8.0, center=13, sigma=2.5)
+        y += np.random.normal(size=len(x), scale=0.1)
+
+        mod = Model(gaussian)
+        params = mod.make_params(sigma=2.2, center=10, amplitude=10)
+        # carefully selected to have inexact floating-point representation
+        params['sigma'].min = 2.2 - 0.95
+        params['sigma'].max = 2.2 + 0.95
+
+        result = mod.fit(y, params, x=x)
+        print(result.fit_report())
+        self.assertTrue(result.params['sigma'].value > 2.3)
+        self.assertTrue(result.params['sigma'].value < 2.7)
+        self.assertTrue(result.params['sigma'].stderr is not None)
+        self.assertTrue(result.params['amplitude'].stderr is not None)
+        self.assertTrue(result.params['sigma'].stderr > 0.02)
+        self.assertTrue(result.params['sigma'].stderr < 0.50)
+
+    def test_unprefixed_name_collisions(self):
+        # tests Github Issue 710
+        np.random.seed(0)
+        x = np.linspace(0, 20, 201)
+        y = 6 + x * 0.55 + gaussian(x, 4.5, 8.5, 2.1) + np.random.normal(size=len(x), scale=0.03)
+
+        def myline(x, a, b):
+            return a + b * x
+
+        def mygauss(x, a, b, c):
+            return gaussian(x, a, b, c)
+
+        mod = Model(myline, prefix='line_') + Model(mygauss, prefix='peak_')
+        pars = mod.make_params(line_a=5, line_b=1, peak_a=10, peak_b=10, peak_c=5)
+        pars.add('a', expr='line_a + peak_a')
+
+        result = mod.fit(y, pars, x=x)
+        self.assertTrue(result.params['peak_a'].value > 4)
+        self.assertTrue(result.params['peak_a'].value < 5)
+        self.assertTrue(result.params['peak_b'].value > 8)
+        self.assertTrue(result.params['peak_b'].value < 9)
+        self.assertTrue(result.params['peak_c'].value > 1.5)
+        self.assertTrue(result.params['peak_c'].value < 2.5)
+        self.assertTrue(result.params['line_a'].value > 5.5)
+        self.assertTrue(result.params['line_a'].value < 6.5)
+        self.assertTrue(result.params['line_b'].value > 0.25)
+        self.assertTrue(result.params['line_b'].value < 0.75)
+        self.assertTrue(result.params['a'].value > 10)
+        self.assertTrue(result.params['a'].value < 11)
+
     def test_composite_model_with_expr_constrains(self):
         """Smoke test for composite model fitting with expr constraints."""
         y = [0, 0, 4, 2, 1, 8, 21, 21, 23, 35, 50, 54, 46, 70, 77, 87, 98,
@@ -809,4 +1349,3 @@ class TestExpression(CommonTests, unittest.TestCase):
 
         data_components = comp_model.eval_components(x=x)
         self.assertIn('exp', data_components)
-#
